uses C code to quickly calculate all non-edges as a two column matrix given an adjacency matrix. i.e. all zeros in the adjacency matrix will correspond to a row in the non-edgelist nonE
Y_to_nonE(N, NnonE, directed, Y)A matrix of the non-edges with NnonE rows and 2 columns where NnonE is the number of non-edges.
number of nodes
number of non-edges
logical indicator of directedness; TRUE=>directed FALSE=>undirected
input adjacency matrix
Michael Salter-Townshend
Y_to_E, Y_to_M, E_to_Y