Learn R Programming

VBLPCM (version 2.4.9)

vblpcmKL: print and returns the Kullback-Leibler divergence from the fitted vblpcm object to the true LPCM posterior

Description

print and returns the Kullback-Leibler divergence from the fitted vblpcm object to the true LPCM posterior

Usage

vblpcmKL(x)

Arguments

x

The fitted values; output from vblpcmfit() or vblpcmstart()

Author

Michael Salter-Townshend

Details

The normalising constant of the posterior is unknown and therefore the Kullback-Leibler divergence is missing a constant.