powered by
print and returns the Kullback-Leibler divergence from the fitted vblpcm object to the true LPCM posterior
vblpcmKL(x)
The fitted values; output from vblpcmfit() or vblpcmstart()
Michael Salter-Townshend
The normalising constant of the posterior is unknown and therefore the Kullback-Leibler divergence is missing a constant.